
exports.up = async function(knex, Promise) {
    await knex.schema.createTable('announcements', function (table){
        table.inherits('messages');
        table.specificType('authors', knex.raw('varchar(128)[]'));
        table.integer('views').defaultTo(0);
    });
    await knex.schema.createTable('events', function (table){
        table.inherits('messages');
        table.string('location');
        table.dateTime('start_time');
        table.dateTime('end_time');
        table.boolean('is_announcement');
        table.specificType('authors', knex.raw('varchar(128)[]'));
    });
    await knex.schema.createTable('group_message_relationships', function(table){
        table.integer('message').notNullable();
        table.string('group').notNullable();
        table.enum('status', ['join', 'host', 'publish']).notNullable();
    });
    await knex.schema.createTable('user_participation', function(table){
        table.integer('event').notNullable();
        table.string('user_uid').notNullable();
        table.enum('user_db', ['ldap']).notNullable().defaultTo('ldap');
    });
    return;
};

exports.down = async function(knex, Promise) {
    await knex.schema.dropTable('group_message_relationships');
    await knex.schema.dropTable('user_participation');
    let event_posts = await knex.select().from('events');
    let announcement_posts = await knex.select().from('announcements');
    await knex.schema.dropTable('events');
    await knex.schema.dropTable('announcements');
    await knex('messages').insert(event_posts);
    await knex('messages').insert(announcement_posts);
    return;
};
